Vector with 100 examples of titles from papers. Is used as an example to build an abstracts class.
example_title.RdVector with 100 examples of titles from papers. Is used as an example to build an abstracts class.
Usage
data(example_title)Examples
data(example_title)